[![PyPI Shield](https://img.shields.io/pypi/v/mit-d3m.svg)](https://pypi.python.org/pypi/mit-d3m)
[![Travis CI Shield](https://travis-ci.org/HDI-Project/mit-d3m.svg?branch=master)](https://travis-ci.org/HDI-Project/mit-d3m)

# mit-d3m

MIT tools to work with D3M datasets.

- Free software: MIT license
- Documentation: https://HDI-Project.github.io/mit-d3m
- Homepage: https://github.com/HDI-Project/mit-d3m
